@@ -59,12 +59,12 @@ class ITRFtoNAD83:
     @staticmethod
     def _coord_type_to_proj4(coord_type: CoordType) -> str:
         if coord_type == CoordType.GEOG:
-            return "+proj=longlat +ellps=GRS80 +no_defs"
+            return "+proj=longlat +datum=WGS84 +no_defs"
         if coord_type == CoordType.CART:
-            return "+proj=cart +ellps=GRS80 +no_defs"
+            return "+proj=cart +datum=WGS84 +no_defs"
         else:
             zone = int(coord_type.value[3:])
-            return f"+proj=utm +zone={zone} +ellps=GRS80 +units=m +no_defs"
+            return f"+proj=utm +zone={zone} +datum=WGS84 +units=m +no_defs"
 
     def _coord_3d_to_4d(self, coord: T_Coord3D) -> T_Coord4D:
         return coord[0], coord[1], coord[2], self.s_epoch
@@ -84,7 +84,7 @@ class ITRFtoNAD83:
             coords = trans.itransform(coords, direction=self.direction)
         return map(self._coord_4d_to_3d, coords)
 
-    
+
 class NAD83toITRF(ITRFtoNAD83):
     """This class is the same as ITRFtoNAD83, but does all transformations in reverse."""
     direction = TransformDirection.INVERSE
@@ -169,7 +169,7 @@ class CSRSTransformer(object):
 
     def validate_crs(self, ref_frame: Reference, vd: Optional[VerticalDatum]):
         if self.is_itrf(ref_frame):
-            assert vd is VerticalDatum.GRS80, f"{ref_frame} must use VerticalDatum GRS80."
+            assert vd is VerticalDatum.WGS84, f"{ref_frame} must use VerticalDatum WGS84."
 
     def __call__(self, coords: Iterable[T_Coord3D]) -> Iterable[T_Coord3D]:
         """
